import { BackendOutputEntry, BackendOutputStorageStrategy, DeepPartial } from '@aws-amplify/plugin-types';
import { Stack } from 'aws-cdk-lib';
/**
 * Implementation of BackendOutputStorageStrategy that stores config data in stack metadata and outputs
 */
export declare class StackMetadataBackendOutputStorageStrategy implements BackendOutputStorageStrategy<BackendOutputEntry> {
    private readonly stack;
    private lazyListValueMap;
    /**
     * Initialize the instance with a stack.
     *
     * If the stack is an AmplifyStack, set a parameter in SSM so the stack can be identified later by the project environment
     */
    constructor(stack: Stack);
    /**
     * Store construct output as stack output and add metadata to the metadata object.
     */
    addBackendOutputEntry: (keyName: string, backendOutputEntry: BackendOutputEntry) => void;
    /**
     * Lazily construct and append to output list as stack output and add metadata to the metadata object.
     */
    appendToBackendOutputList: (keyName: string, backendOutputEntry: DeepPartial<BackendOutputEntry>) => void;
    /**
     * Add or update metadata entry.
     * @param existingMetadataEntry - The existing metadata entry.
     * @param keyName - The key name.
     * @param backendOutputEntry - The backend output entry.
     */
    private addOrUpdateMetadata;
}
//# sourceMappingURL=stack_metadata_output_storage_strategy.d.ts.map